@@ -10,8 +10,6 @@
 
 /* Please keep this in alphabetical order */
 static gchar *contributors[] = {
-	N_("GNOME was brought to you by"),
-	" ",
 	"Jerome Abela",
 	"Lauri Alanko",
 	"Seth Alves",
@@ -39,6 +37,7 @@ static gchar *contributors[] = {
 	"Andreas Bolsch",
 	"Dario Bressanini",
 	"Emmanuel Briot",
+	"Stephen Browne",
 	"Marcus Brubaker",
 	"Christian Bucher",
 	"Dave Camp",
@@ -47,6 +46,9 @@ static gchar *contributors[] = {
 	"Chema Celorio",
 	"Damon Chaplin",
 	"Kevin Charter",
+	/* CJK people please use (U5F35) (U570B) (U51A0) to replace
+	 * this name */
+	N_("Abel Cheung"),
 	"Kenneth Rohde Christiansen",
 	"Chad Clark",
 	"Matthias Clasen",
@@ -106,6 +108,7 @@ static gchar *contributors[] = {
 	"Alan Aspuru Guzik",
 	"Telsa Gwynne",
 	"Fredrik Hallenberg",
+        "Mikael Hallendal",
 	"Lars Hamann",
 	"Michael Hanni",
 	"Raja R Harinath",
@@ -120,6 +123,9 @@ static gchar *contributors[] = {
 	"Miguel de Icaza",
 	"Tim Janik",
 	"Stefan Jeske",
+	/* Wang is the surname. CJK people, please use (U738B) (U5251)
+	 * to replace this name. */
+	N_("Wang Jian"),
 	"Michael K. Johnson",
 	"Andy Kahn",
 	"Sami Kananoja",
@@ -142,6 +148,7 @@ static gchar *contributors[] = {
 	"Birger Langkjer",
 	"Alexander Larsson",
 	"Guillaume Laurent",
+	"Ole Laursen",
 	"Michael Lausch",
 	"Will LaShell",
 	"Jens Lautenbacher",
@@ -157,6 +164,7 @@ static gchar *contributors[] = {
 	"Nick Lopez",
 	"Dirk Lutjens",
 	"Josh MacDonald",
+	"Paolo Maggi",
 	"Sam Magnuson",
 	"Ian Main",
 	"Mandrake",
@@ -189,10 +197,12 @@ static gchar *contributors[] = {
 	N_("Alexandre Muniz"),
 	/* Name in Hangeul is: Ub0a8 Uc131 Ud604 */
 	N_("Sung-Hyun Nam"),
+	"Deepa Natarajan",
 	"Karl Nelson",
 	"Asger Alstrup Nielsen",
 	"Seth Nickell",
 	"Eric Nielson",
+	"Bastien Nocera",
 	/* If your encodings allows it, use adiaeresis (U00E4) for the 'ae'
 	 * of 'Norbaeck' */
 	N_("Martin Norbaeck"),
@@ -207,7 +217,7 @@ static gchar *contributors[] = {
 	"Cameron Parish",
 	"Conrad Parker",
 	"Stuart Parmenter",
-	"Nils Pederson",
+	"Nils Pedersen",
 	"Havoc Pennington",
 	"Ettore Perazzoli",
 	/* If your encoding allows it, use oacute (U00F3) for the 'o'
@@ -239,6 +249,7 @@ static gchar *contributors[] = {
 	/* Name in Japanese is: U7b39 U5c71 U548c U5b8f */
 	N_("Kazuhiro Sasayama"),
 	"Carsten Schaar",
+	"Christian Schaller",
 	"Franck Schneider",
 	"Ingo Schneider",
 	"Bernd Schroeder",
@@ -262,6 +273,7 @@ static gchar *contributors[] = {
 	N_("The Squeaky Rubber Gnome"),
 	"Maciej Stachowiak",
 	"Stalyn",
+	"Jakub Steiner",
 	"Ben Stern",
 	"Micah Stetson",
 	"Nathan Carl Summers",
@@ -291,15 +303,14 @@ static gchar *contributors[] = {
 	"David Winkler",
 	"Jeremy Wise",
 	"Roger Wolff",
+	"Frank Worsley",
 	"James Youngman",
 	"Orest Zborowski",
 	"Sascha Ziemann",
 	"Michael Zucchi",
 	"Jason van Zyl",
-	"Christian F.K. Schaller",
-	" ",
-	N_("... and many more"),
-	NULL, NULL
+	"",
+	""
 };
 
 
